@@ -60,34 +60,6 @@ sub set {
 sub to_string {
     my $self = shift;
     return Data::Dumper->Dump( [ $self ] ); 
-#   my $result = "";
-#   $result .= "Mismatches   : " . $self->mismatches . "\n"
-#     if $self->mismatches_isset;
-#   $result .= "Insertions   : " . $self->insertions . "\n"
-#     if $self->insertions_isset;
-#   $result .= "Deletions    : " . $self->deletions . "\n"
-#     if $self->deletions_isset;
-#   $result .= "Edit distance: " . $self->editdistance . "\n"
-#     if $self->editdistance_isset;
-#   $result .= "No alignments: " . $self->no_alignments . "\n"
-#     if $self->no_alignments_isset;
-#   $result .= "Query        : " . $self->query . "\n" if $self->query_isset;
-#   $result .= "Query File   : " . $self->query_file . "\n" if
-#   $self->query_file_isset;
-#   $result .= "Querylength  : " . $self->query_length . "\n"
-#     if $self->query_length_isset;
-#   $result .= "Revcom       : " . $self->reverse_complement . "\n" if $self->reverse_complement_isset;
-##   $result .= "Subject      : " . $self->subject . "\n" if $self->subject_isset;
-#   $result .= "GU Mismatches: " . $self->gumismatches . "\n";
-#   $result .= "upstream     : " . $self->upstream . "\n";
-#   $result .= "downstream   : " . $self->downstream . "\n";
-#   $result .= "maxhits      : " . $self->maxhits . "\n" if
-#       $self->maxhits_isset;
-#   $result .= "filters      : " . Dumper($self->filters) . "\n" if $self->filters_isset;
-#   $result .= "Data Path    : " . $self->datapath . "\n";
-#   $result .= "Database     : " . $self->database . "\n";
-#   $result .= "Tmp Path     : " . $self->tmppath . "\n";
-#   return $result;
 }
 1;# Magic true value required at end of module
 __END__
@@ -134,7 +106,7 @@ Bio::Grep::Container::SearchSettings - Data structure for all search settings
 
 =head1 DESCRIPTION
 
-Backends::SearchSettings is a data structure for storing all search settings.
+B<Bio::Grep::Container::SearchSettings> is the data structure for all search settings.
 Not all back-ends will support every option.
 
 =head1 METHODS
@@ -189,24 +161,30 @@ Get/Set allowed mismatches
 
    $sbe->settings->mismatches(5)
 
+Not available in the GUUGle backend.
 
 =item C<editdistance()>
 
-Get/Set allowed edit distance. Not all back-ends will support this feature!
+Get/Set allowed edit distance. 
 
+Only available in the Vmatch and Agrep back-end.
 
 =item C<upstream()>
 
 Get/set upstream. This is the number of bases upstream the match.
  
    $sbe->settings->upstream( 10 );
-   
+
+Not available in the Agrep backend.
+
 =item C<downstream()>
 
 Get/set downstream. This is the number of bases downstream the match.
    
    $sbe->settings->downstream( 10 );
 
+Not available in the Agrep backend.
+
 =item C<filters()>
 
 Get/set the filters. This is an array of modules based on L<Bio::Grep::Filter::FilterI>.
@@ -219,6 +197,8 @@ Get/set the filters. This is an array of modules based on L<Bio::Grep::Filter::F
 
    $sbe->settings->filters( ( $filter1, $filter2 ) );
 
+Not available in the Agrep backend.
+
 =item C<datapath()>
 
 Get/set the datapath. This is the path to the databases for the back-end.
@@ -252,13 +232,14 @@ Not available (meaning not necessary) in the Vmatch and GUUGle back-end.
 Get/set online. Vmatch back-end allows searching without using the index. When
 you allow many mismatches, this could be faster. 
 
+Only available in the Vmatch and HyPa back-end.
+
 =item C<sort()>
 
-Get set sort mode. 
+Get set sort mode. You can get an hash with all available sort modes (including
+a description from the back-end:
 
-=item C<to_string()> 
-
-This function returns a string representation of this object
+  my %sort_modes = $sbe->available_sort_modes();
 
 =item C<maxhits()>
 
@@ -273,6 +254,18 @@ Get/set gumismatches. Tells the back-end how it should count GU mismatches.
 
 Only available in the HyPa and GUUGle back-end.
 
+=item C<query_length()>
+
+Get/Set the query length. Initialized with length of the query string. If
+this member variable is smaller then the query string, then the back-end will
+search for all substrings of that size. 
+
+Only available in the Vmatch and GUUGle back-end.
+
+=item C<to_string()> 
+
+This function returns a string representation of this object
+
 
 =back
 
@@ -288,12 +281,6 @@ Only available in the Vmatch back-end.
 
     $sbe->settings->complete(1);
 
-=item C<query_length()>
-
-Get/Set the query length. Initialized with length of the query string. If
-this member variable is smaller then the query string, then the back-end will
-search for all substrings of that size. 
-
 =item C<showdesc()>
 
 Get/Set showdesc. This vmatch command line option makes the Vmatch parser
